(function($) {

  Drupal.behaviors.urban_airship_web_push_notifications = {
    attach: function ( context, settings ) {

      var optin_prompt = $( '.uawn-opt-in-prompt', context );
      var hide_optin_prompt = settings.urban_airship_web_push_notifications.hide_optin_prompt;
      var prompt_notifications = settings.urban_airship_web_push_notifications.prompt_notifications;
      // Values in page views:
      var page_views = parseInt( settings.urban_airship_web_push_notifications.page_views );
      var temporarily_disable = parseInt( settings.urban_airship_web_push_notifications.temporarily_disable );
      var uawn_pv = _uawnGetCookie( 'uawn_pv' );
      var uawn = _uawnGetCookie( 'uawn' );
      var uawn_cookie_params = 7;

      $( document ).ready(function() {
        _uawnPageViewCounter();
      });

      // Make sure a user hasn't click Dismiss button.
      if ( prompt_notifications == 'on_page_load' ) {
        _uawnShowPrompt();
      }
      else {
        if ( uawn_pv >= page_views ) {
          _uawnShowPrompt();
        }
      }

      // Receive web notifications
      $( '.uawn-opt-in-allow', context ).click(function() {
        UA.then(function( sdk ) {
          sdk.register();
          optin_prompt.hide();
        });
      });

      var jqueryVersion = window.jQuery.fn.jquery.split('.').join('');

      // Button opt-in prompt type
      if ( jqueryVersion > 1900 ) {
        $( document.body ).on( 'click', '.uawn-button', function(e) {
          UA.then(function( sdk ) {
            sdk.register();
          });
        });
      }
      else {
        $( document.body ).delegate( '.uawn-button', 'click', function(e) {
          UA.then(function( sdk ) {
            sdk.register();
          });
        });
      }

      // Hide opt-in prompt for now and make it reappear
      // after N page visits. This logic applies only when user dismisses opt-in prompt.
      $( '.uawn-opt-in-dismiss', context ).click(function() {
        if ( temporarily_disable > 0 ) {
          _uawnResetPageViewCounter();
        }
        optin_prompt.hide();
      });

      function _uawnPageViewCounter() {
        // Count page views.
        if ( uawn_pv === null ) {
          uawn_pv = 1;
        }
        else {
          uawn_pv = parseInt( uawn_pv ) + 1;
        }
        _uawnSetCookie( 'uawn_pv', uawn_pv, uawn_cookie_params );
      }

      function _uawnResetPageViewCounter() {
        _uawnSetCookie( 'uawn', true, uawn_cookie_params );
        _uawnSetCookie( 'uawn_pv', 0, uawn_cookie_params );
      }

      // Add button prompt to the page.
      function _uawnInitBellButton() {
        var contents = $( '.uawn-opt-in-prompt-button' ).html();
        $( '.uawn-button' ).each(function() {
          $(this).html( contents );
        });
      }

      function _uawnShowPrompt() {
        UA.then(function( sdk ) {
        // Only show opt-in prompt when user hasn't already subscribed
          if ( sdk.isSupported && sdk.canRegister ) {
            if ( sdk.channel === null || ( _uawnIsObject( sdk.channel ) && sdk.channel.opt_in === false ) ) {
              _uawnInitBellButton();
              if ( hide_optin_prompt ) {
                if ( uawn === null ) {
                  sdk.register();
                  _uawnResetPageViewCounter();
                }
                else {
                  if ( temporarily_disable > 0 && uawn_pv >= temporarily_disable ) {
                    sdk.register();
                    _uawnResetPageViewCounter();
                  }
                }
              }
              else {
                if ( uawn === null ) {
                  optin_prompt.show();
                }
                else {
                  if ( temporarily_disable > 0 && uawn_pv >= temporarily_disable ) {
                    optin_prompt.show();
                  }
                }
              }
            }
          }
        });
      }

      function _uawnSetCookie( name, value, days ) {
        var expires = "";
        if ( days ) {
          var date = new Date();
          date.setTime( date.getTime() + ( days * 24 * 60 * 60 * 1000 ) );
          expires = "; expires=" + date.toUTCString();
        }
        document.cookie = name + "=" + value + expires + "; path=/";
      }

      function _uawnGetCookie( name ) {
        var nameEQ = name + "=";
        var ca = document.cookie.split( ';' );
        for ( var i = 0; i < ca.length; i++ ) {
          var c = ca[ i ];
          while ( c.charAt( 0 ) == ' ' ) c = c.substring( 1, c.length );
          if ( c.indexOf( nameEQ ) == 0 ) return c.substring( nameEQ.length, c.length );
        }
        return null;
      }

      function _uawnIsObject( val ) {
        if ( val === null ) { return false; }
        return ( ( typeof val === 'function' ) || ( typeof val === 'object' ) );
      }

    }
  };

})(jQuery);
