<?php

/**
 * Trigger notifications.
 */
class Notification {

  /**
   * Replace tokens and send message.
   */
  public function send($node) {
    if (user_access('send urban airship web push notifications')) {
      if (empty(variable_get('urban_airship_web_push_notifications_app_key')) || empty(variable_get('urban_airship_web_push_notifications_app_master_secret'))) {
        watchdog('urban_airship_web_push_notifications', 'Invalid credentials', array(), WATCHDOG_WARNING);
        return;
      }
      if (!empty($node->urban_airship_web_push_notifications)) {
        $body = $node->urban_airship_web_push_notifications_text;
        $scheduled = $node->urban_airship_web_push_notifications_scheduled;
        $url = $node->urban_airship_web_push_notifications_action_url;
        if (module_exists('token')) {
          $body = token_replace($body, array('node' => $node));
        }
        $icon = '';
        if (!empty($node->urban_airship_web_push_notifications_icon)) {
          $file = file_load($node->urban_airship_web_push_notifications_icon);
          $icon = file_create_url($file->uri);
        }
        $notification = array(
          'title' => $node->urban_airship_web_push_notifications_title,
          'body' => !empty($body) ? $body : $node->title,
          'icon' => $icon,
          'url' => !empty($url) ? $url : url('node/' . $node->nid, array('absolute' => TRUE)),
          'interaction' => !empty($node->urban_airship_web_push_notifications_interaction),
          'scheduled' => !empty($scheduled) ? format_date(strtotime($scheduled), 'custom', 'Y-m-d\TH:i:s') : '',
        );
        // Other modules can override notification messages if needed.
        drupal_alter('urban_airship_web_push_notifications', $notification, $node);
        $this->logNotification($notification, $node);
        $push = (new PushApi())
          ->setAudience('all')
          ->setDeviceTypes('web')
          ->setNotification($notification);
        if ($node->urban_airship_web_push_notifications == 1) {
          // Instant notifications.
          $push->send();
        }
        else {
          // Schedule notifications.
          (new SchedulesApi())
            ->setName($node->title)
            ->setLocalScheduledTime($notification['scheduled'])
            ->setPush($push->getData())
            ->schedule();
        }
      }
    }
  }

  /**
   * Track notification.
   */
  protected function logNotification($notification, $node) {
    global $user;
    $username = '';
    if ($account = user_load($user->uid)) {
      $username = $account->name;
    }
    db_insert('urban_airship_web_push_notifications')
      ->fields(array(
        'username' => $username,
        'nid' => $node->nid,
        'notification_title' => $notification['title'],
        'notification_text' => $notification['body'],
        'notification_icon' => $notification['icon'],
        'notification_action_url' => $notification['url'],
        'sent_at' => REQUEST_TIME,
      ))
      ->execute();
  }
}
