<?php

/**
 * Urban Airship Push API Integration.
 */
class PushApi {

  protected $audience;
  protected $device_types;
  protected $notification;

  /**
   * Set Audience
   * @see https://docs.urbanairship.com/api/ua/#audience-selectors
   */
  public function setAudience($audience) {
    $this->audience = $audience;
    return $this;
  }

  /**
   * Get Audience
   */
  public function getAudience() {
    return $this->audience;
  }

  /**
   * Set Device Types
   * @see https://docs.urbanairship.com/api/ua/#push-object
   */
  public function setDeviceTypes($types) {
    $this->device_types = $types;
    return $this;
  }

  /**
   * Get Device Types
   */
  public function getDeviceTypes() {
    return ($this->device_types != 'all') ? [$this->device_types] : $this->device_types;
  }

  /**
   * Set Notification message
   * @see https://docs.urbanairship.com/api/ua/#push-object
   */
  public function setNotification($notification) {
    if (is_array($notification)) {
      if (!empty($notification['title'])) {
        $this->notification['web']['title'] = $notification['title'];
      }
      if (!empty($notification['body'])) {
        $this->notification['alert'] = $notification['body'];
        $this->notification['web']['alert'] = $notification['body'];
      }
      if (!empty($notification['icon'])) {
        $this->notification['web']['icon']['url'] = $notification['icon'];
      }
      if (!empty($notification['url'])) {
        $this->notification['actions']['open'] = [
          'type'    => 'url',
          'content' => $notification['url'],
        ];
      }
      if (!empty($notification['interaction'])) {
        $this->notification['web']['require_interaction'] = TRUE;
      }
    }
    else {
      $this->notification = [
        'alert' => $notification,
      ];
    }
    return $this;
  }

  /**
   * Get Notification message
   */
  public function getNotification() {
    return $this->notification;
  }

  /**
   * Build Push Object
   * @see https://docs.urbanairship.com/api/ua/#push-object
   */
  public function getData() {
    return array(
      'audience' => $this->getAudience(),
      'device_types' => $this->getDeviceTypes(),
      'notification' => $this->getNotification(),
    );
  }

  /**
   * Send notification to Urban Airship
   * @see https://docs.urbanairship.com/api/ua/#push-api
   */
  public function send() {
    try {
      $response = drupal_http_request('https://go.urbanairship.com/api/push', array(
        'headers' => $this->headers(),
        'data' => json_encode($this->getData()),
        'method' => 'POST',
      ));
      watchdog('urban_airship_web_push_notifications', 'Notification successfully sent', array(), WATCHDOG_INFO);
    }
    catch (RequestException $e) {
      watchdog('urban_airship_web_push_notifications', $e->getMessage(), array(), WATCHDOG_ERROR);
    }
  }

  /**
   * Authentication
   */
  protected function headers() {
    return array(
      'Accept' => 'application/vnd.urbanairship+json; version=3',
      'Content-Type' => 'application/json',
      'Authorization' => 'Basic ' 
        . base64_encode(variable_get('urban_airship_web_push_notifications_app_key')
        . ':'
        . variable_get('urban_airship_web_push_notifications_app_master_secret')),
    );
  }

}
