<?php

/**
 * Urban Airship Schedules API Integration.
 */

class SchedulesApi {

  protected $name;
  protected $local_scheduled_time;
  protected $push;

  /**
   * Set Name
   * @see https://docs.urbanairship.com/api/ua/#schedules-api
   */
  public function setName($name) {
    $this->name = $name;
    return $this;
  }

  /**
   * Get Name
   */
  public function getName() {
    return $this->name;
  }

  /**
   * Set Scheduled Time
   * @see https://docs.urbanairship.com/api/ua/#schedules-api
   */
  public function setLocalScheduledTime($local_scheduled_time) {
    $this->local_scheduled_time = $local_scheduled_time;
    return $this;
  }

  /**
   * Get Scheduled Time
   */
  public function getLocalScheduledTime() {
    return array('local_scheduled_time' => $this->local_scheduled_time);
  }

  /**
   * Set Push API object
   * @see https://docs.urbanairship.com/api/ua/#push-object
   * @see https://docs.urbanairship.com/api/ua/#schedules-api
   */
  public function setPush($push) {
    $this->push = $push;
    return $this;
  }

  /**
   * Get Push API object
   */
  public function getPush() {
    return $this->push;
  }

  /**
   * Build Push Object
   * @see https://docs.urbanairship.com/api/ua/#push-object
   */
  public function getData() {
    return array(
      'name' => $this->getName(),
      'schedule' => $this->getLocalScheduledTime(),
      'push' => $this->getPush(),
    );
  }

  /**
   * Send scheduled notification to Urban Airship
   * @see https://docs.urbanairship.com/api/ua/#schedules-api
   */
  public function schedule() {
    try {
      $response = drupal_http_request('https://go.urbanairship.com/api/schedules', [
        'headers' => $this->headers(),
        'data' => json_encode($this->getData()),
        'method' => 'POST',
      ]);
      watchdog('urban_airship_web_push_notifications', 'Notification successfully scheduled', array(), WATCHDOG_INFO);
    }
    catch (RequestException $e) {
      watchdog('urban_airship_web_push_notifications', $e->getMessage(), array(), WATCHDOG_ERROR);
    }
  }

  /**
   * Authentication
   */
  protected function headers() {
    return array(
      'Accept' => 'application/vnd.urbanairship+json; version=3',
      'Content-Type' => 'application/json',
      'Authorization' => 'Basic ' 
        . base64_encode(variable_get('urban_airship_web_push_notifications_app_key')
        . ':'
        . variable_get('urban_airship_web_push_notifications_app_master_secret')),
    );
  }

}
