<?php

/**
 * @file
 * Urban Airship Web Notify Admin pages.
 */

/**
 * Credentials form
 */
function urban_airship_web_push_notifications_credentials_form() {
  drupal_set_title(t('Urban Airship Web Push Notifications'));
  $form = array();
  $form['info'] = array(
    '#markup' => t('<p>To use this module, you’ll need a Web Notify account from Urban Airship. <a href="https://www.urbanairship.com/products/web-push-notifications/pricing" target="_blank">Sign up for a free</a> starter plan with unlimited web push notifications and up to 1,000 addressable users.</p>
      <p>Credentials can be found in your Urban Airship dashboard. <a href="https://go.urbanairship.com/accounts/login/" target="_blank">Visit your Urban Airship dashboard</a>.</p>'),
  );
  $form['urban_airship_web_push_notifications_app_key'] = array(
    '#type'          => 'textfield',
    '#title'         => t('App Key'),
    '#description'   => t('Urban Airship generated string identifying the app setup. Used in the application bundle.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_app_key'),
    '#required'      => TRUE,
  );
  $form['urban_airship_web_push_notifications_app_master_secret'] = array(
    '#type'          => 'textfield',
    '#title'         => t('App Master Secret'),
    '#description'   => t('Urban Airship generated string used for server to server API access. This should never be shared or placed in an application bundle.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_app_master_secret'),
    '#required'      => TRUE,
  );
  return system_settings_form($form);
}

/**
 * SDK Bundle form
 */
function urban_airship_web_push_notifications_sdk_bundle_form() {
  drupal_set_title(t('Urban Airship Web Push Notifications'));
  $form = array();
  if (class_exists('ZipArchive')) {
    $form['info'] = array(
      '#markup' => t('<p>Your SDK zip file can be found in your Urban Airship dashboard. If you need to find this file after completing initial configuration or if you would like to make updates to your configuration, navigate to <em>Platforms</em> under the Settings drop-down in the <a href="https://go.urbanairship.com/accounts/login/" target="_blank">Urban Airship Dashboard</a> and then click <em>Edit</em> on the Web Notify service to expose the <em>Download SDK Bundle</em> button.</p>
          <p>For more information about the contents of the SDK bundle, please see the <a href="https://docs.urbanairship.com/platform/web" target="_blank">Urban Airship documentation</a>.</p>'),
    );
    $form['bundle_sdk'] = array(
      '#type' => 'managed_file',
      '#title' => t('Zip File'),
      '#progress_message' => t('Please wait...'),
      '#progress_indicator' => 'bar',
      '#description' => t('SDK Bundle Zip file.'),
      '#required' => TRUE,
      '#upload_location' => 'public://urban-airship/',
      '#upload_validators' => array(
        'file_validate_extensions' => array('zip'),
      ),
      '#default_value' => variable_get('urban_airship_web_push_notifications_bundle_sdk')
    );
    $form['save'] = array(
      '#type' => 'submit',
      '#value' => t('Save SDK Bundle'),
      '#weight' => 10,
    );
  }
  else {
    $form['info'] = array(
      '#markup' => t("<p><em>ZipArchive</em> class couldn't be found. Please configure SDK Bundle in <em>settings.php</em>. Instructions can be found in the <em>Readme.md</em> file.</p>"),
    );
  }
  $push_worker_js = (new PushWorkerJs())->parse();
  if (!empty($push_worker_js)) {
    $visible_params = array(
      'defaultTitle' => array(
        'label' => t('Default Title'),
        'description' => t('Default notification title. The default title can be changed in your Urban Airship dashboard or overridden in node forms.'),
      ),
      'defaultIcon' => array(
        'label' => t('Default Icon'),
        'description' => t('Default notification icon. The default icon can be changed in your Urban Airship dashboard or overridden in node forms.'),
      ),
    );
    $default_values = array();
    foreach ($visible_params as $k => $info) {
      $v = ($k == 'defaultIcon' && !empty($push_worker_js[$k])) ? '<img src="' . $push_worker_js[$k] . '" style="max-wdith: 45px" border="0">' : $push_worker_js[$k];
      $default_values[] = '<div class="default-param">
          <div class="default-param-name"><strong>' . $info['label'] . '</strong></div>
          <div class="default-param-value">' . $v . '</div>
          <div class="description">' . $info['description'] . '</div>
        </div>';
    }
    if (!empty($default_values)) {
      $form['default_value'] = [
        '#markup' => '<div class="default-values">' . join("\n", $default_values) . '</div><br/>'
      ];
    }
  }
  return $form;
}

/** 
 * Save SDK Bundle file.
 */
function urban_airship_web_push_notifications_sdk_bundle_form_submit($form, &$form_state) {
  if (!empty($form_state['values']['bundle_sdk'])) {
    $file = file_load($form_state['values']['bundle_sdk']);
    $file->status = FILE_STATUS_PERMANENT;
    file_usage_add($file, 'urban_airship_web_push_notifications', 'sdk_bundle_fid', $file->fid);
    file_save($file);
    variable_set('urban_airship_web_push_notifications_bundle_sdk', $file->fid);
    $items = _urban_airship_web_push_notifications_bundle_unzip(drupal_realpath($file->uri));
    variable_set('urban_airship_web_push_notifications_push-worker.js', $items['push-worker.js']);
    variable_set('urban_airship_web_push_notifications_snippet.html', $items['snippet.html']);
    variable_set('urban_airship_web_push_notifications_secure-bridge.html', $items['secure-bridge.html']);
  }
  else {
    $fid = variable_get('urban_airship_web_push_notifications_bundle_sdk');
    $file = file_load($fid);
    file_delete($file, TRUE);
    variable_del('urban_airship_web_push_notifications_bundle_sdk');
    variable_del('urban_airship_web_push_notifications_push-worker.js');
    variable_del('urban_airship_web_push_notifications_snippet.html');
    variable_del('urban_airship_web_push_notifications_secure-bridge.html');
  }
  drupal_set_message(t('The configuration options have been saved.'));
}

/**
 * Opt-in form
 */
function urban_airship_web_push_notifications_optin_form() {
  drupal_set_title(t('Urban Airship Web Push Notifications'));
  $form = array();
  $form['info'] = array(
    '#markup' => t('<p>For additional details on creating or using a custom opt-in, please see the <a href="https://docs.urbanairship.com/platform/web/#registration-ui" target="_blank">Urban Airship documentation</a>.</p>'),
  );
  $form['urban_airship_web_push_notifications_hide_optin_prompt'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Do not use custom Opt-In Prompt'),
    '#description'   => t('If box is checked, no custom prompt will be shown. Instead, users will only see the required default browser prompt for notification permission.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_hide_optin_prompt', FALSE),
  );
  $form['urban_airship_web_push_notifications_optin_prompt_type'] = array(
    '#type'          => 'radios',
    '#title'         => t('Prompt Type'),
    '#description'   => t('Select prompt type.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_prompt_type', 'modal'),
    '#options'       => array(
      'modal'  => t('Modal'),
      'banner' => t('Banner'),
      'button' => t('Button'),
    ),
    '#states' => array(
      'invisible' => array(
        ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE)
      ),
    ),
  );
  drupal_add_css(drupal_get_path('module', 'urban_airship_web_push_notifications') . '/assets/css/opt-in-prompt.css');
  drupal_add_js(drupal_get_path('module', 'urban_airship_web_push_notifications') . '/assets/js/opt-in-prompt-example.js');
  $optin_prompt_bell_icon_path = base_path() . drupal_get_path('module', 'urban_airship_web_push_notifications') . '/assets/img/bell.svg';
  $form['optin_prompt_example'] = array(
    '#markup' => '<div class="uawn-opt-in-prompt-example">
      <h4>' . t('Opt-in Prompt Example') . '</h4>
      <div class="uawn-opt-in-prompt prompt-modal example">
        <div class="optin-message">' . t('Want to stay up to date with the latest breaking news alerts?') . '</div>
        <div class="optin-buttons-wrapper">
          <span id="uawn-opt-in-allow" class="prompt-button btn-prompt-allow">' . t('Ok') . '</span>
          <span id="uawn-opt-in-dismiss" class="prompt-button btn-prompt-dismiss">' . t('Not Now') . '</span>
        </div>
      </div>
      <div class="uawn-opt-in-prompt prompt-banner example">
        <div class="prompt-banner-wrapper">
          <div class="optin-message">' . t('Want to stay up to date with the latest breaking news alerts?') . '</div>
          <div class="optin-buttons-wrapper">
            <span id="uawn-opt-in-dismiss" class="prompt-button btn-prompt-dismiss">' . t('Not Now') . '</span>
            <span id="uawn-opt-in-allow" class="prompt-button btn-prompt-allow">' . t('Ok') . '</span>
          </div>
        </div>
      </div>
      <div class="uawn-opt-in-prompt prompt-button example">
        <div class="optin-buttons-wrapper">
          <span id="uawn-opt-in-allow" class="prompt-button btn-prompt-allow"><img src="' . $optin_prompt_bell_icon_path . '" width="30"></span>
        </div>
        <div class="uawn-button-snippet">
          <p><div class="descr optional">' . t('Optionally, use this HTML snippet to place a button in your page templates:') . '</div>
            <div class="descr">' . t('Use this HTML snippet to place the button in your page templates:') . '</div></p>
          <div class="uawn-button-html-code">&lt;div class="uawn-button">&lt;/div></div>
        </div>
      </div>
    </div>'
  );
  $form['urban_airship_web_push_notifications_optin_prompt'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Opt-in Prompt'),
    '#description'   => t('Customize the text for your opt-in prompt. The prompt displays to your website visitors and should give them some context as to what to expect from your notifications. For example, "Want to stay up to date with the latest breaking news alerts?"'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_prompt', 'Want to stay up to date with the latest breaking news alerts?'),
    '#attributes'    => array(
      'placeholder' => t('Notification message')
    ),
    '#states' => array(
      'invisible' => array(
        ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE),
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_optin_allow_label'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Allow Label'),
    '#description'   => t('Label of the button on the prompt used for allowing notifications. Examples include: Allow or Yes'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_allow_label', 'Yes'),
    '#size'          => 20,
    '#attributes'    => array(
      'placeholder' => t('Yes')
    ),
    '#states' => array(
      'invisible' => array(
        ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE),
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_optin_dismiss_label'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Dismiss Label'),
    '#description'   => t('Label of the button used for dismissing the prompt. Examples include: Not Now, Maybe Later, or No Thanks'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_dismiss_label', 'Not Now'),
    '#size'          => 20,
    '#attributes'    => array(
      'placeholder' => t('Not Now')
    ),
    '#states' => array(
      'invisible' => array(
        ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE),
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_optin_banner_position'] = array(
    '#type'          => 'select',
    '#title'         => t('Banner Position'),
    '#description'   => t('Customize where on the page to display the banner opt-in prompt, such as the top of the page or bottom.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_banner_position', 'top'),
    '#options'       => array(
      'top'    => t('Top'),
      'bottom' => t('Bottom'),
    ),
    '#states' => array(
      'invisible' => array(
        array(
          ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE)
        ),
        array(
          ':input[name="urban_airship_web_push_notifications_optin_prompt_type"]' => array('value' => 'modal'),
        ),
        array(
          ':input[name="urban_airship_web_push_notifications_optin_prompt_type"]' => array('value' => 'button'),
        )
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_optin_position'] = array(
    '#type'          => 'select',
    '#title'         => t('Position'),
    '#description'   => t('Customize where on the page to display the opt-in prompt, such as the middle of the page or the bottom left corner.'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_optin_position', 'bottom-left'),
    '#options'       => array(
      'top-left'      => t('Top Left'),
      'top-center'    => t('Top Center'),
      'top-right'     => t('Top Right'),
      'middle'        => t('Middle'),
      'bottom-left'   => t('Bottom Left'),
      'bottom-center' => t('Bottom Center'),
      'bottom-right'  => t('Bottom Right'),
    ),
    '#states' => array(
      'invisible' => array(
        array(
          ':input[name="urban_airship_web_push_notifications_hide_optin_prompt"]' => array('checked' => TRUE)
        ),
        array(
          ':input[name="urban_airship_web_push_notifications_optin_prompt_type"]' => array('value' => 'banner'),
        ),
        array(
          ':input[name="urban_airship_web_push_notifications_optin_prompt_type"]' => array('value' => 'button'),
        )
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_prompt_notifications'] = array(
    '#type'          => 'radios',
    '#title'         => t('Prompt for Notifications'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_prompt_notifications', 'on_page_load'),
    '#options'       => array(
      'on_page_load'  => t('Display opt-in prompt on page load'),
      'on_page_views' => t('Display opt-in prompt after specified number of page visits'),
    ),
  );
  $form['urban_airship_web_push_notifications_page_views'] = array(
    '#type'          => 'textfield',
    '#size'          => 20,
    '#title'         => t('Number of page visits'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_page_views', 1),
    '#description'   => t('Numeric value to set page views'),
    '#states' => array(
      'visible' => array(
        ':input[name="urban_airship_web_push_notifications_prompt_notifications"]' => array('value' => 'on_page_views'),
      ),
    ),
  );
  $form['urban_airship_web_push_notifications_temporarily_disable'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Temporarily disable Opt-In Prompt'),
    '#default_value' => variable_get('urban_airship_web_push_notifications_temporarily_disable', 10),
    '#description'   => t('Temporarily disable the opt-in prompt for a specified number of page views when a user dismisses the prompt without allowing notifications.'),
    '#size'          => 20,
  );
  $form['optin_prompt_button_example'] = array(
    '#markup' => '<div id="button-html-snippet" class="uawn-opt-in-prompt-example">
      <div class="uawn-opt-in-prompt prompt-button example">
        <div class="optin-buttons-wrapper">
          <span id="uawn-opt-in-allow" class="prompt-button btn-prompt-allow"><img src="' . $optin_prompt_bell_icon_path . '" width="30"></span>
        </div>
        <div class="uawn-button-snippet">
          <p>' . t('Optionally, use this HTML snippet to place a button in your page templates. This button may be used in combination with the default browser prompt.') . '</p>
          <div class="uawn-button-html-code">&lt;div class="uawn-button">&lt;/div></div>
        </div>
      </div>
    </div>'
  );
  return system_settings_form($form);
}

/**
 * Get contents of the Bundle file.
 */
function _urban_airship_web_push_notifications_bundle_unzip($path) {
  $items = array();
  $zip = new ZipArchive();
  if ($zip->open($path) === TRUE) {
    for ($i = 0; $i < $zip->numFiles; $i++) {
      $filename = $zip->getNameIndex($i);
      $handle = fopen('zip://' . $path . '#' . $filename, 'r');
      $contents = '';
      while (!feof($handle)) {
        $contents .= fread($handle, 8192);
      }
      fclose($handle);
      $items[$filename] = $contents;
    }
    $zip->close();
  }
  return $items;
}
